@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_syswm.h,v 1.4.2.7 2001/02/28 12:35:28 hercules Exp $";
+ "@(#) $Id: SDL_syswm.h,v 1.4 2001/05/22 05:05:16 hercules Exp $";
 #endif
 
 /* Include file for SDL custom system window manager hooks */
@@ -95,6 +95,21 @@ typedef struct {
 	} info;
 } SDL_SysWMinfo;
 
+#elif defined(ENABLE_NANOX)
+#include <microwin/nano-X.h>
+
+/* The generic custom event structure */
+struct SDL_SysWMmsg {
+	SDL_version version;
+	int data;
+};
+
+/* The windows custom window manager information structure */
+typedef struct {
+	SDL_version version ;
+	GR_WINDOW_ID window ;	/* The display window */
+} SDL_SysWMinfo;
+
 #elif defined(WIN32)
 #include <windows.h>
 
