@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL.c,v 1.5.2.14 2001/02/10 07:20:03 hercules Exp $";
+ "@(#) $Id: SDL.c,v 1.3 2001/05/23 23:35:09 hercules Exp $";
 #endif
 
 /* Initialization code for SDL */
@@ -231,3 +231,21 @@ const SDL_version * SDL_Linked_Version(void)
 	return(&version);
 }
 
+#if defined(_WIN32_WCE)
+/* Need to include DllMain() on Windows CE for some reason.. */
+#include <windows.h>
+
+BOOL APIENTRY DllMain( HANDLE hModule, 
+                       DWORD  ul_reason_for_call, 
+                       LPVOID lpReserved )
+{
+	switch (ul_reason_for_call) {
+		case DLL_PROCESS_ATTACH:
+		case DLL_THREAD_ATTACH:
+		case DLL_THREAD_DETACH:
+		case DLL_PROCESS_DETACH:
+			break;
+	}
+	return TRUE;
+}
+#endif /* _WIN32_WCE */
