@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_mixer.c,v 1.4.2.5 2001/02/10 07:20:03 hercules Exp $";
+ "@(#) $Id: SDL_mixer.c,v 1.2 2001/04/26 16:50:17 hercules Exp $";
 #endif
 
 /* This provides the default mixing callback for the SDL audio routines */
@@ -96,7 +96,7 @@ static const Uint8 mix8[] =
 #define ADJUST_VOLUME(s, v)	(s = (s*v)/SDL_MIX_MAXVOLUME)
 #define ADJUST_VOLUME_U8(s, v)	(s = (((s-128)*v)/SDL_MIX_MAXVOLUME)+128)
 
-void SDL_MixAudio (Uint8 *dst, Uint8 *src, Uint32 len, int volume)
+void SDL_MixAudio (Uint8 *dst, const Uint8 *src, Uint32 len, int volume)
 {
 	Uint16 format;
 
