@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_sysaudio.h,v 1.6.2.17 2001/03/21 17:19:56 hercules Exp $";
+ "@(#) $Id: SDL_sysaudio.h,v 1.6 2001/06/16 01:51:42 hercules Exp $";
 #endif
 
 #ifndef _SDL_sysaudio_h
@@ -99,11 +99,6 @@ typedef struct AudioBootStrap {
 	SDL_AudioDevice *(*create)(int devindex);
 } AudioBootStrap;
 
-#if defined(unix) && \
-   !defined(linux) && !defined(__FreeBSD__) && !defined(__CYGWIN32__) \
-   && !defined(__bsdi__)
-extern AudioBootStrap AUDIO_bootstrap;
-#endif
 #ifdef OSS_SUPPORT
 extern AudioBootStrap DSP_bootstrap;
 extern AudioBootStrap DMA_bootstrap;
@@ -111,6 +106,13 @@ extern AudioBootStrap DMA_bootstrap;
 #ifdef ALSA_SUPPORT
 extern AudioBootStrap ALSA_bootstrap;
 #endif
+#ifdef __OpenBSD__
+extern AudioBootStrap OBSD_bootstrap;
+#endif
+#if (defined(unix) && !defined(__CYGWIN32__)) && \
+    !defined(OSS_SUPPORT) && !defined(ALSA_SUPPORT)
+extern AudioBootStrap AUDIO_bootstrap;
+#endif
 #ifdef ARTSC_SUPPORT
 extern AudioBootStrap ARTSC_bootstrap;
 #endif
@@ -126,14 +128,20 @@ extern AudioBootStrap DSOUND_bootstrap;
 #ifdef ENABLE_WINDIB
 extern AudioBootStrap WAVEOUT_bootstrap;
 #endif
+#ifdef _AIX
+extern AudioBootStrap Paud_bootstrap;
+#endif
 #ifdef __BEOS__
 extern AudioBootStrap BAUDIO_bootstrap;
 #endif
 #if defined(macintosh) || TARGET_API_MAC_CARBON
 extern AudioBootStrap SNDMGR_bootstrap;
 #endif
-#ifdef _AIX
-extern AudioBootStrap Paud_bootstrap;
+#ifdef ENABLE_AHI
+extern AudioBootStrap AHI_bootstrap;
+#endif
+#ifdef DISKAUD_SUPPORT
+extern AudioBootStrap DISKAUD_bootstrap;
 #endif
 
 /* This is the current audio device */
