@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_dspaudio.c,v 1.1.2.5 2001/03/21 17:19:56 hercules Exp $";
+ "@(#) $Id: SDL_dspaudio.c,v 1.3 2001/05/23 00:36:17 hercules Exp $";
 #endif
 
 /* Allow access to a raw mixing buffer */
@@ -37,18 +37,7 @@ static char rcsid =
 #include <sys/time.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
-#ifdef linux
-#include <linux/soundcard.h>
-#endif
-#ifdef __bsdi__
 #include <sys/soundcard.h>
-#endif
-#ifdef __FreeBSD__
-#include <machine/soundcard.h>
-#endif
-#ifdef __USLC__
-#include <sys/soundcard.h>
-#endif
 
 #include "SDL_audio.h"
 #include "SDL_error.h"
