@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_yuv_sw.c,v 1.1.2.14 2001/02/22 00:21:51 hercules Exp $";
+ "@(#) $Id: SDL_yuv_sw.c,v 1.3 2001/04/27 20:25:25 hercules Exp $";
 #endif
 
 /* This is the software implementation of the YUV video overlay support */
@@ -1299,6 +1299,9 @@ void SDL_FreeYUV_SW(_THIS, SDL_Overlay *overlay)
 
 	swdata = overlay->hwdata;
 	if ( swdata ) {
+		if ( swdata->stretch ) {
+			SDL_FreeSurface(swdata->stretch);
+		}
 		if ( swdata->pixels ) {
 			free(swdata->pixels);
 		}
