@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_cgxmodes_c.h,v 1.1.2.2 2001/02/10 07:20:06 hercules Exp $";
+ "@(#) $Id: SDL_cgxmodes_c.h,v 1.3 2001/05/10 20:13:29 hercules Exp $";
 #endif
 
 /* Utilities for getting and setting the X display mode */
@@ -40,5 +40,10 @@ extern int CGX_GetVideoModes(_THIS);
 extern SDL_Rect **CGX_ListModes(_THIS, SDL_PixelFormat *format, Uint32 flags);
 extern void CGX_FreeVideoModes(_THIS);
 extern int CGX_ResizeFullScreen(_THIS);
+/*
+extern void CGX_WaitMapped(_THIS, Window win);
+extern void CGX_WaitUnmapped(_THIS, Window win);
+extern void CGX_QueueEnterFullScreen(_THIS);
+*/
 extern int CGX_EnterFullScreen(_THIS);
 extern int CGX_LeaveFullScreen(_THIS);
