@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_fbvideo.c,v 1.13.2.29 2001/02/28 12:06:12 hercules Exp $";
+ "@(#) $Id: SDL_fbvideo.c,v 1.3 2001/04/26 17:05:23 hercules Exp $";
 #endif
 
 /* Framebuffer console based SDL video driver implementation.
@@ -271,7 +271,7 @@ static int FB_AddMode(_THIS, int index, unsigned int w, unsigned int h)
 	}
 
 	/* Only allow a mode if we have a valid timing for it */
-	next_mode = 0;
+	next_mode = -1;
 	for ( i=0; i<(sizeof(vesa_timings)/sizeof(vesa_timings[0])); ++i ) {
 		if ( (w == vesa_timings[i].xres) &&
 		     (h == vesa_timings[i].yres) && vesa_timings[i].pixclock ) {
@@ -279,7 +279,7 @@ static int FB_AddMode(_THIS, int index, unsigned int w, unsigned int h)
 			break;
 		}
 	}
-	if ( ! next_mode ) {
+	if ( next_mode == -1 ) {
 #ifdef FBCON_DEBUG
 		fprintf(stderr, "No valid timing line for mode %dx%d\n", w, h);
 #endif
