@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_romvideo.c,v 1.1.2.13 2001/02/12 11:09:57 hercules Exp $";
+ "@(#) $Id: SDL_romvideo.c,v 1.3 2001/06/07 14:28:11 hercules Exp $";
 #endif
 
 #include <stdio.h>
@@ -34,7 +34,7 @@ static char rcsid =
    is still at the back on MacOS X, which is where this code is needed.
  */
 #if USE_QUICKTIME
-#include <Movies.h>
+#include <QuickTime/Movies.h>
 #endif
 #else
 #include <LowMem.h>
