@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_syswm.c,v 1.4.2.8 2001/02/13 10:05:50 hercules Exp $"
+ "@(#) $Id: SDL_syswm.c,v 1.3 2001/05/23 23:35:10 hercules Exp $"
 #endif
 
 #include <stdio.h>
@@ -213,8 +213,8 @@ void WIN_SetWMCaption(_THIS, const char *title, const char *icon)
 {
 #ifdef _WIN32_WCE
 	/* WinCE uses the UNICODE version */
-	int nLen = strlen(title);
-	LPWSTR lpszW = alloca((nLen+1)*2);
+	int nLen = strlen(title)+1;
+	LPWSTR lpszW = alloca(nLen*2);
 	MultiByteToWideChar(CP_ACP, 0, title, -1, lpszW, nLen);
 	SetWindowText(SDL_Window, lpszW);
 #else
