@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_dibevents.c,v 1.2.2.11 2001/02/13 10:05:50 hercules Exp $";
+ "@(#) $Id: SDL_dibevents.c,v 1.3 2001/05/23 23:35:10 hercules Exp $";
 #endif
 
 #include <stdlib.h>
@@ -303,14 +303,13 @@ int DIB_CreateWindow(_THIS)
 {
 #ifdef _WIN32_WCE
 	/* WinCE uses the UNICODE version */
-	int nLen = strlen(SDL_Appname);
-	LPWSTR lpszW = alloca((nLen+1)*2);
+	int nLen = strlen(SDL_Appname)+1;
+	LPWSTR lpszW = alloca(nLen*2);
 	MultiByteToWideChar(CP_ACP, 0, SDL_Appname, -1, lpszW, nLen);
 
 	SDL_RegisterApp("SDL_app", 0, 0);
-	SDL_Window = CreateWindow(lpszW, lpszW,
-                        (WS_OVERLAPPED|WS_CAPTION|WS_SYSMENU|WS_MINIMIZEBOX),
-                                 0, 0, 0, 0, NULL, NULL, SDL_Instance, NULL);
+	SDL_Window = CreateWindow(lpszW, lpszW, WS_VISIBLE,
+                                  0, 0, 0, 0, NULL, NULL, SDL_Instance, NULL);
 	if ( SDL_Window == NULL ) {
 		SDL_SetError("Couldn't create window");
 		return(-1);
