@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_dibvideo.c,v 1.5.2.30 2001/02/13 10:05:50 hercules Exp $";
+ "@(#) $Id: SDL_dibvideo.c,v 1.5 2001/06/07 13:53:51 hercules Exp $";
 #endif
 
 #include <stdio.h>
@@ -440,8 +440,10 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 			(WS_POPUP);
 	const DWORD windowstyle = 
 			(WS_OVERLAPPED|WS_CAPTION|WS_SYSMENU|WS_MINIMIZEBOX);
+#ifndef _WIN32_WCE
 	const DWORD resizestyle =
 			(WS_THICKFRAME|WS_MAXIMIZEBOX);
+#endif
 	int binfo_size;
 	BITMAPINFO *binfo;
 	HDC hdc;
@@ -453,10 +455,12 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 	/* See whether or not we should center the window */
 	was_visible = IsWindowVisible(SDL_Window);
 
+#ifdef HAVE_OPENGL
 	/* Clean up any GL context that may be hanging around */
 	if ( current->flags & SDL_OPENGL ) {
 		WIN_GL_ShutDown(this);
 	}
+#endif /* HAVE_OPENGL */
 
 	/* Recalculate the bitmasks if necessary */
 	if ( bpp == current->format->BitsPerPixel ) {
@@ -518,24 +522,28 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 		settings.dmFields = DM_PELSWIDTH | DM_PELSHEIGHT | DM_BITSPERPEL;
 		if ( ChangeDisplaySettings(&settings, CDS_FULLSCREEN) == DISP_CHANGE_SUCCESSFUL ) {
 			video->flags |= SDL_FULLSCREEN;
-			if ( screen_pal != NULL ) {
-			/*	RJR: March 28, 2000
-				delete identity palette if switching from a palettized mode */
-				DeleteObject(screen_pal);
-				screen_pal = NULL;
-			}
-			if ( bpp <= 8 )
-			{
-			/*	RJR: March 28, 2000
-				create identity palette switching to a palettized mode */
-				screen_pal = DIB_CreatePalette(bpp);
-			}
 		}
 	}
 #endif /* !NO_CHANGEDISPLAYSETTINGS */
 
+	/* Reset the palette and create a new one if necessary */
+	if ( screen_pal != NULL ) {
+	/*	RJR: March 28, 2000
+		delete identity palette if switching from a palettized mode */
+		DeleteObject(screen_pal);
+		screen_pal = NULL;
+	}
+	if ( bpp <= 8 )
+	{
+	/*	RJR: March 28, 2000
+		create identity palette switching to a palettized mode */
+		screen_pal = DIB_CreatePalette(bpp);
+	}
+
 	style = GetWindowLong(SDL_Window, GWL_STYLE);
+#ifndef _WIN32_WCE
 	style &= ~(resizestyle|WS_MAXIMIZE);
+#endif
 	if ( (video->flags & SDL_FULLSCREEN) == SDL_FULLSCREEN ) {
 		style &= ~windowstyle;
 		style |= directstyle;
@@ -553,11 +561,15 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 			style &= ~directstyle;
 			style |= windowstyle;
 			if ( flags & SDL_RESIZABLE ) {
+#ifndef _WIN32_WCE
 				style |= resizestyle;
+#endif
 				video->flags |= SDL_RESIZABLE;
 			}
 		}
+#ifndef _WIN32_WCE
 		if (IsZoomed(SDL_Window)) style |= WS_MAXIMIZE;
+#endif
 	}
 	SetWindowLong(SDL_Window, GWL_STYLE, style);
 
@@ -642,7 +654,11 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 		bounds.top = 0;
 		bounds.right = video->w;
 		bounds.bottom = video->h;
+#ifndef _WIN32_WCE
 		AdjustWindowRect(&bounds, GetWindowLong(SDL_Window, GWL_STYLE), FALSE);
+#else
+		AdjustWindowRectEx(&bounds, GetWindowLong(SDL_Window, GWL_STYLE), FALSE,0);
+#endif
 		width = bounds.right-bounds.left;
 		height = bounds.bottom-bounds.top;
 		x = (GetSystemMetrics(SM_CXSCREEN)-width)/2;
@@ -650,7 +666,11 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 		if ( y < 0 ) { /* Cover up title bar for more client area */
 			y -= GetSystemMetrics(SM_CYCAPTION)/2;
 		}
+#ifndef _WIN32_WCE
 		swp_flags = (SWP_NOCOPYBITS | SWP_NOZORDER | SWP_SHOWWINDOW);
+#else
+		swp_flags = (SWP_NOZORDER | SWP_SHOWWINDOW);
+#endif
 		if ( was_visible && !(flags & SDL_FULLSCREEN) ) {
 			swp_flags |= SWP_NOMOVE;
 		}
@@ -659,6 +679,7 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 		SetForegroundWindow(SDL_Window);
 	}
 
+#ifdef HAVE_OPENGL
 	/* Set up for OpenGL */
 	if ( flags & SDL_OPENGL ) {
 		if ( WIN_GL_SetupWindow(this) < 0 ) {
@@ -666,6 +687,8 @@ SDL_Surface *DIB_SetVideoMode(_THIS, SDL_Surface *current,
 		}
 		video->flags |= SDL_OPENGL;
 	}
+#endif /* HAVE_OPENGL */
+
 	/* We're live! */
 	return(video);
 }
@@ -711,7 +734,11 @@ int DIB_SetColors(_THIS, int firstcolor, int ncolors, SDL_Color *colors)
 {
 	RGBQUAD *pal;
 	int i;
+#ifndef _WIN32_WCE
 	HDC hdc, mdc;
+#else
+	HDC hdc;
+#endif
 
 	/* Update the display palette */
 	hdc = GetDC(SDL_Window);
@@ -723,7 +750,11 @@ int DIB_SetColors(_THIS, int firstcolor, int ncolors, SDL_Color *colors)
 			entries[i].peRed   = colors[i].r;
 			entries[i].peGreen = colors[i].g;
 			entries[i].peBlue  = colors[i].b;
+#ifndef _WIN32_WCE
 			entries[i].peFlags = PC_NOCOLLAPSE;
+#else
+			entries[i].peFlags = 0;
+#endif
 		}
 		SetPaletteEntries(screen_pal, firstcolor, ncolors, entries);
 		SelectPalette(hdc, screen_pal, FALSE);
@@ -740,12 +771,14 @@ int DIB_SetColors(_THIS, int firstcolor, int ncolors, SDL_Color *colors)
 	}
 
 	/* Set the DIB palette and update the display */
+#ifndef _WIN32_WCE
 	mdc = CreateCompatibleDC(hdc);
 	SelectObject(mdc, screen_bmp);
 	SetDIBColorTable(mdc, firstcolor, ncolors, pal);
 	BitBlt(hdc, 0, 0, this->screen->w, this->screen->h,
 	       mdc, 0, 0, SRCCOPY);
 	DeleteDC(mdc);
+#endif
 	ReleaseDC(SDL_Window, hdc);
 	return(1);
 }
@@ -857,9 +890,11 @@ void DIB_VideoQuit(_THIS)
 				ChangeDisplaySettings(NULL, 0);
 			}
 #endif
+#ifdef HAVE_OPENGL
 			if ( this->screen->flags & SDL_OPENGL ) {
 				WIN_GL_ShutDown(this);
 			}
+#endif /* HAVE_OPENGL */
 			this->screen->pixels = NULL;
 		}
 		if ( screen_bmp ) {
