@@ -22,7 +22,7 @@
 
 #ifdef SAVE_RCSID
 static char rcsid =
- "@(#) $Id: SDL_dx5events.c,v 1.3.2.12 2001/02/10 07:20:09 hercules Exp $";
+ "@(#) $Id: SDL_dx5events.c,v 1.3 2001/06/16 01:01:42 hercules Exp $";
 #endif
 
 /* CAUTION!!!!  If you modify this file, check ../windib/SDL_sysevents.c */
@@ -379,6 +379,20 @@ static void handle_mouse(const int numevents, DIDEVICEOBJECTDATA *ptrbuf)
 			case DIMOFS_Y:
 				yrel += (Sint16)ptrbuf[i].dwData;
 				break;
+			case DIMOFS_Z:
+				if ( xrel || yrel ) {
+					posted = SDL_PrivateMouseMotion(
+							0, 1, xrel, yrel);
+					xrel = 0;
+					yrel = 0;
+				}
+				if((int)ptrbuf[i].dwData > 0)
+					posted = SDL_PrivateMouseButton(
+							SDL_PRESSED, 4, 0, 0);
+				else if((int)ptrbuf[i].dwData < 0)
+					posted = SDL_PrivateMouseButton(
+							SDL_PRESSED, 5, 0, 0);
+				break;
 			case DIMOFS_BUTTON0:
 			case DIMOFS_BUTTON1:
 			case DIMOFS_BUTTON2:
